@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -263,8 +263,8 @@ class QuotaControllerAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.servicecontrol_v1.types.AllocateQuotaRequest, dict]]):
-                The request object. Request message for the
-                AllocateQuota method.
+                The request object. Request message for the AllocateQuota
+                method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -307,7 +307,7 @@ class QuotaControllerAsyncClient:
         # Done; return the response.
         return response
 
-    async def __aenter__(self):
+    async def __aenter__(self) -> "QuotaControllerAsyncClient":
         return self
 
     async def __aexit__(self, exc_type, exc, tb):
