@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -51,6 +51,7 @@ from google.cloud.servicecontrol_v1.types import metric_value, quota_controller
 from .transports.base import DEFAULT_CLIENT_INFO, QuotaControllerTransport
 from .transports.grpc import QuotaControllerGrpcTransport
 from .transports.grpc_asyncio import QuotaControllerGrpcAsyncIOTransport
+from .transports.rest import QuotaControllerRestTransport
 
 
 class QuotaControllerClientMeta(type):
@@ -66,6 +67,7 @@ class QuotaControllerClientMeta(type):
     )  # type: Dict[str, Type[QuotaControllerTransport]]
     _transport_registry["grpc"] = QuotaControllerGrpcTransport
     _transport_registry["grpc_asyncio"] = QuotaControllerGrpcAsyncIOTransport
+    _transport_registry["rest"] = QuotaControllerRestTransport
 
     def get_transport_class(
         cls,
@@ -470,8 +472,8 @@ class QuotaControllerClient(metaclass=QuotaControllerClientMeta):
 
         Args:
             request (Union[google.cloud.servicecontrol_v1.types.AllocateQuotaRequest, dict]):
-                The request object. Request message for the
-                AllocateQuota method.
+                The request object. Request message for the AllocateQuota
+                method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
