@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,14 +19,18 @@ from typing import Dict, Type
 from .base import QuotaControllerTransport
 from .grpc import QuotaControllerGrpcTransport
 from .grpc_asyncio import QuotaControllerGrpcAsyncIOTransport
+from .rest import QuotaControllerRestInterceptor, QuotaControllerRestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[QuotaControllerTransport]]
 _transport_registry["grpc"] = QuotaControllerGrpcTransport
 _transport_registry["grpc_asyncio"] = QuotaControllerGrpcAsyncIOTransport
+_transport_registry["rest"] = QuotaControllerRestTransport
 
 __all__ = (
     "QuotaControllerTransport",
     "QuotaControllerGrpcTransport",
     "QuotaControllerGrpcAsyncIOTransport",
+    "QuotaControllerRestTransport",
+    "QuotaControllerRestInterceptor",
 )
