@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -270,8 +270,7 @@ class ServiceControllerAsyncClient:
 
         Args:
             request (Optional[Union[google.cloud.servicecontrol_v1.types.CheckRequest, dict]]):
-                The request object. Request message for the Check
-                method.
+                The request object. Request message for the Check method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -421,7 +420,7 @@ class ServiceControllerAsyncClient:
         # Done; return the response.
         return response
 
-    async def __aenter__(self):
+    async def __aenter__(self) -> "ServiceControllerAsyncClient":
         return self
 
     async def __aexit__(self, exc_type, exc, tb):
