@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,7 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-from google.cloud.servicecontrol import gapic_version as package_version
+from google.cloud.servicecontrol_v2 import gapic_version as package_version
 
 __version__ = package_version.__version__
 
@@ -28,6 +28,7 @@ from .types.service_controller import (
     ReportRequest,
     ReportResponse,
     ResourceInfo,
+    ResourceInfoList,
 )
 
 __all__ = (
@@ -37,5 +38,6 @@ __all__ = (
     "ReportRequest",
     "ReportResponse",
     "ResourceInfo",
+    "ResourceInfoList",
     "ServiceControllerClient",
 )
