@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -53,6 +53,7 @@ from google.cloud.servicecontrol_v2.types import service_controller
 from .transports.base import DEFAULT_CLIENT_INFO, ServiceControllerTransport
 from .transports.grpc import ServiceControllerGrpcTransport
 from .transports.grpc_asyncio import ServiceControllerGrpcAsyncIOTransport
+from .transports.rest import ServiceControllerRestTransport
 
 
 class ServiceControllerClientMeta(type):
@@ -68,6 +69,7 @@ class ServiceControllerClientMeta(type):
     )  # type: Dict[str, Type[ServiceControllerTransport]]
     _transport_registry["grpc"] = ServiceControllerGrpcTransport
     _transport_registry["grpc_asyncio"] = ServiceControllerGrpcAsyncIOTransport
+    _transport_registry["rest"] = ServiceControllerRestTransport
 
     def get_transport_class(
         cls,
@@ -489,8 +491,7 @@ class ServiceControllerClient(metaclass=ServiceControllerClientMeta):
 
         Args:
             request (Union[google.cloud.servicecontrol_v2.types.CheckRequest, dict]):
-                The request object. Request message for the Check
-                method.
+                The request object. Request message for the Check method.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
