@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,14 +19,18 @@ from typing import Dict, Type
 from .base import ServiceControllerTransport
 from .grpc import ServiceControllerGrpcTransport
 from .grpc_asyncio import ServiceControllerGrpcAsyncIOTransport
+from .rest import ServiceControllerRestInterceptor, ServiceControllerRestTransport
 
 # Compile a registry of transports.
 _transport_registry = OrderedDict()  # type: Dict[str, Type[ServiceControllerTransport]]
 _transport_registry["grpc"] = ServiceControllerGrpcTransport
 _transport_registry["grpc_asyncio"] = ServiceControllerGrpcAsyncIOTransport
+_transport_registry["rest"] = ServiceControllerRestTransport
 
 __all__ = (
     "ServiceControllerTransport",
     "ServiceControllerGrpcTransport",
     "ServiceControllerGrpcAsyncIOTransport",
+    "ServiceControllerRestTransport",
+    "ServiceControllerRestInterceptor",
 )
