@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -19,6 +19,7 @@ from .service_controller import (
     ReportRequest,
     ReportResponse,
     ResourceInfo,
+    ResourceInfoList,
 )
 
 __all__ = (
@@ -27,4 +28,5 @@ __all__ = (
     "ReportRequest",
     "ReportResponse",
     "ResourceInfo",
+    "ResourceInfoList",
 )
