@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,6 +22,8 @@ try:
 except ImportError:  # pragma: NO COVER
     import mock
 
+from collections.abc import Iterable
+import json
 import math
 
 from google.api import distribution_pb2  # type: ignore
@@ -33,12 +35,15 @@ from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
 from google.oauth2 import service_account
 from google.protobuf import any_pb2  # type: ignore
+from google.protobuf import json_format
 from google.protobuf import timestamp_pb2  # type: ignore
 import grpc
 from grpc.experimental import aio
 from proto.marshal.rules import wrappers
 from proto.marshal.rules.dates import DurationRule, TimestampRule
 import pytest
+from requests import PreparedRequest, Request, Response
+from requests.sessions import Session
 
 from google.cloud.servicecontrol_v1.services.quota_controller import (
     QuotaControllerAsyncClient,
@@ -98,6 +103,7 @@ def test__get_default_mtls_endpoint():
     [
         (QuotaControllerClient, "grpc"),
         (QuotaControllerAsyncClient, "grpc_asyncio"),
+        (QuotaControllerClient, "rest"),
     ],
 )
 def test_quota_controller_client_from_service_account_info(
@@ -113,7 +119,11 @@ def test_quota_controller_client_from_service_account_info(
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == ("servicecontrol.googleapis.com:443")
+        assert client.transport._host == (
+            "servicecontrol.googleapis.com:443"
+            if transport_name in ["grpc", "grpc_asyncio"]
+            else "https://servicecontrol.googleapis.com"
+        )
 
 
 @pytest.mark.parametrize(
@@ -121,6 +131,7 @@ def test_quota_controller_client_from_service_account_info(
     [
         (transports.QuotaControllerGrpcTransport, "grpc"),
         (transports.QuotaControllerGrpcAsyncIOTransport, "grpc_asyncio"),
+        (transports.QuotaControllerRestTransport, "rest"),
     ],
 )
 def test_quota_controller_client_service_account_always_use_jwt(
@@ -146,6 +157,7 @@ def test_quota_controller_client_service_account_always_use_jwt(
     [
         (QuotaControllerClient, "grpc"),
         (QuotaControllerAsyncClient, "grpc_asyncio"),
+        (QuotaControllerClient, "rest"),
     ],
 )
 def test_quota_controller_client_from_service_account_file(
@@ -168,13 +180,18 @@ def test_quota_controller_client_from_service_account_file(
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == ("servicecontrol.googleapis.com:443")
+        assert client.transport._host == (
+            "servicecontrol.googleapis.com:443"
+            if transport_name in ["grpc", "grpc_asyncio"]
+            else "https://servicecontrol.googleapis.com"
+        )
 
 
 def test_quota_controller_client_get_transport_class():
     transport = QuotaControllerClient.get_transport_class()
     available_transports = [
         transports.QuotaControllerGrpcTransport,
+        transports.QuotaControllerRestTransport,
     ]
     assert transport in available_transports
 
@@ -191,6 +208,7 @@ def test_quota_controller_client_get_transport_class():
             transports.QuotaControllerGrpcAsyncIOTransport,
             "grpc_asyncio",
         ),
+        (QuotaControllerClient, transports.QuotaControllerRestTransport, "rest"),
     ],
 )
 @mock.patch.object(
@@ -346,6 +364,18 @@ def test_quota_controller_client_client_options(
             "grpc_asyncio",
             "false",
         ),
+        (
+            QuotaControllerClient,
+            transports.QuotaControllerRestTransport,
+            "rest",
+            "true",
+        ),
+        (
+            QuotaControllerClient,
+            transports.QuotaControllerRestTransport,
+            "rest",
+            "false",
+        ),
     ],
 )
 @mock.patch.object(
@@ -545,6 +575,7 @@ def test_quota_controller_client_get_mtls_endpoint_and_cert_source(client_class)
             transports.QuotaControllerGrpcAsyncIOTransport,
             "grpc_asyncio",
         ),
+        (QuotaControllerClient, transports.QuotaControllerRestTransport, "rest"),
     ],
 )
 def test_quota_controller_client_client_options_scopes(
@@ -585,6 +616,7 @@ def test_quota_controller_client_client_options_scopes(
             "grpc_asyncio",
             grpc_helpers_async,
         ),
+        (QuotaControllerClient, transports.QuotaControllerRestTransport, "rest", None),
     ],
 )
 def test_quota_controller_client_client_options_credentials_file(
@@ -854,6 +886,134 @@ async def test_allocate_quota_field_headers_async():
     ) in kw["metadata"]
 
 
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        quota_controller.AllocateQuotaRequest,
+        dict,
+    ],
+)
+def test_allocate_quota_rest(request_type):
+    client = QuotaControllerClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="rest",
+    )
+
+    # send a request that will satisfy transcoding
+    request_init = {"service_name": "sample1"}
+    request = request_type(**request_init)
+
+    # Mock the http request call within the method and fake a response.
+    with mock.patch.object(type(client.transport._session), "request") as req:
+        # Designate an appropriate value for the returned response.
+        return_value = quota_controller.AllocateQuotaResponse(
+            operation_id="operation_id_value",
+            service_config_id="service_config_id_value",
+        )
+
+        # Wrap the value into a proper Response obj
+        response_value = Response()
+        response_value.status_code = 200
+        pb_return_value = quota_controller.AllocateQuotaResponse.pb(return_value)
+        json_return_value = json_format.MessageToJson(pb_return_value)
+
+        response_value._content = json_return_value.encode("UTF-8")
+        req.return_value = response_value
+        response = client.allocate_quota(request)
+
+    # Establish that the response is the type that we expect.
+    assert isinstance(response, quota_controller.AllocateQuotaResponse)
+    assert response.operation_id == "operation_id_value"
+    assert response.service_config_id == "service_config_id_value"
+
+
+@pytest.mark.parametrize("null_interceptor", [True, False])
+def test_allocate_quota_rest_interceptors(null_interceptor):
+    transport = transports.QuotaControllerRestTransport(
+        credentials=ga_credentials.AnonymousCredentials(),
+        interceptor=None
+        if null_interceptor
+        else transports.QuotaControllerRestInterceptor(),
+    )
+    client = QuotaControllerClient(transport=transport)
+    with mock.patch.object(
+        type(client.transport._session), "request"
+    ) as req, mock.patch.object(
+        path_template, "transcode"
+    ) as transcode, mock.patch.object(
+        transports.QuotaControllerRestInterceptor, "post_allocate_quota"
+    ) as post, mock.patch.object(
+        transports.QuotaControllerRestInterceptor, "pre_allocate_quota"
+    ) as pre:
+        pre.assert_not_called()
+        post.assert_not_called()
+        pb_message = quota_controller.AllocateQuotaRequest.pb(
+            quota_controller.AllocateQuotaRequest()
+        )
+        transcode.return_value = {
+            "method": "post",
+            "uri": "my_uri",
+            "body": pb_message,
+            "query_params": pb_message,
+        }
+
+        req.return_value = Response()
+        req.return_value.status_code = 200
+        req.return_value.request = PreparedRequest()
+        req.return_value._content = quota_controller.AllocateQuotaResponse.to_json(
+            quota_controller.AllocateQuotaResponse()
+        )
+
+        request = quota_controller.AllocateQuotaRequest()
+        metadata = [
+            ("key", "val"),
+            ("cephalopod", "squid"),
+        ]
+        pre.return_value = request, metadata
+        post.return_value = quota_controller.AllocateQuotaResponse()
+
+        client.allocate_quota(
+            request,
+            metadata=[
+                ("key", "val"),
+                ("cephalopod", "squid"),
+            ],
+        )
+
+        pre.assert_called_once()
+        post.assert_called_once()
+
+
+def test_allocate_quota_rest_bad_request(
+    transport: str = "rest", request_type=quota_controller.AllocateQuotaRequest
+):
+    client = QuotaControllerClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
+    )
+
+    # send a request that will satisfy transcoding
+    request_init = {"service_name": "sample1"}
+    request = request_type(**request_init)
+
+    # Mock the http request call within the method and fake a BadRequest error.
+    with mock.patch.object(Session, "request") as req, pytest.raises(
+        core_exceptions.BadRequest
+    ):
+        # Wrap the value into a proper Response obj
+        response_value = Response()
+        response_value.status_code = 400
+        response_value.request = Request()
+        req.return_value = response_value
+        client.allocate_quota(request)
+
+
+def test_allocate_quota_rest_error():
+    client = QuotaControllerClient(
+        credentials=ga_credentials.AnonymousCredentials(), transport="rest"
+    )
+
+
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.QuotaControllerGrpcTransport(
@@ -935,6 +1095,7 @@ def test_transport_get_channel():
     [
         transports.QuotaControllerGrpcTransport,
         transports.QuotaControllerGrpcAsyncIOTransport,
+        transports.QuotaControllerRestTransport,
     ],
 )
 def test_transport_adc(transport_class):
@@ -949,6 +1110,7 @@ def test_transport_adc(transport_class):
     "transport_name",
     [
         "grpc",
+        "rest",
     ],
 )
 def test_transport_kind(transport_name):
@@ -1085,6 +1247,7 @@ def test_quota_controller_transport_auth_adc(transport_class):
     [
         transports.QuotaControllerGrpcTransport,
         transports.QuotaControllerGrpcAsyncIOTransport,
+        transports.QuotaControllerRestTransport,
     ],
 )
 def test_quota_controller_transport_auth_gdch_credentials(transport_class):
@@ -1185,11 +1348,23 @@ def test_quota_controller_grpc_transport_client_cert_source_for_mtls(transport_c
             )
 
 
+def test_quota_controller_http_transport_client_cert_source_for_mtls():
+    cred = ga_credentials.AnonymousCredentials()
+    with mock.patch(
+        "google.auth.transport.requests.AuthorizedSession.configure_mtls_channel"
+    ) as mock_configure_mtls_channel:
+        transports.QuotaControllerRestTransport(
+            credentials=cred, client_cert_source_for_mtls=client_cert_source_callback
+        )
+        mock_configure_mtls_channel.assert_called_once_with(client_cert_source_callback)
+
+
 @pytest.mark.parametrize(
     "transport_name",
     [
         "grpc",
         "grpc_asyncio",
+        "rest",
     ],
 )
 def test_quota_controller_host_no_port(transport_name):
@@ -1200,7 +1375,11 @@ def test_quota_controller_host_no_port(transport_name):
         ),
         transport=transport_name,
     )
-    assert client.transport._host == ("servicecontrol.googleapis.com:443")
+    assert client.transport._host == (
+        "servicecontrol.googleapis.com:443"
+        if transport_name in ["grpc", "grpc_asyncio"]
+        else "https://servicecontrol.googleapis.com"
+    )
 
 
 @pytest.mark.parametrize(
@@ -1208,6 +1387,7 @@ def test_quota_controller_host_no_port(transport_name):
     [
         "grpc",
         "grpc_asyncio",
+        "rest",
     ],
 )
 def test_quota_controller_host_with_port(transport_name):
@@ -1218,7 +1398,33 @@ def test_quota_controller_host_with_port(transport_name):
         ),
         transport=transport_name,
     )
-    assert client.transport._host == ("servicecontrol.googleapis.com:8000")
+    assert client.transport._host == (
+        "servicecontrol.googleapis.com:8000"
+        if transport_name in ["grpc", "grpc_asyncio"]
+        else "https://servicecontrol.googleapis.com:8000"
+    )
+
+
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "rest",
+    ],
+)
+def test_quota_controller_client_transport_session_collision(transport_name):
+    creds1 = ga_credentials.AnonymousCredentials()
+    creds2 = ga_credentials.AnonymousCredentials()
+    client1 = QuotaControllerClient(
+        credentials=creds1,
+        transport=transport_name,
+    )
+    client2 = QuotaControllerClient(
+        credentials=creds2,
+        transport=transport_name,
+    )
+    session1 = client1.transport.allocate_quota._session
+    session2 = client2.transport.allocate_quota._session
+    assert session1 != session2
 
 
 def test_quota_controller_grpc_transport_channel():
@@ -1489,6 +1695,7 @@ async def test_transport_close_async():
 
 def test_transport_close():
     transports = {
+        "rest": "_session",
         "grpc": "_grpc_channel",
     }
 
@@ -1506,6 +1713,7 @@ def test_transport_close():
 
 def test_client_ctx():
     transports = [
+        "rest",
         "grpc",
     ]
     for transport in transports:
